Changelog
---------

0.3.3 (2018-03-21)
~~~~~~~~~~~~~~~~~~~~~

- Fixes missing price leading to error when 'charge fee to customer' is active.
  [href]

0.3.2 (2018-02-09)
~~~~~~~~~~~~~~~~~~~~~

- Fixes oauth not working with latest stripe python release (again).
  [href]

- Requires Python 3.6.
  [href]

0.3.1 (2017-12-27)
~~~~~~~~~~~~~~~~~~~~~

- Fixes oauth not working with latest stripe python release.
  [href]

0.3.0 (2017-10-10)
~~~~~~~~~~~~~~~~~~~~~

- Adds proper support for many-to-many payments.
  [href]

0.2.0 (2017-10-06)
~~~~~~~~~~~~~~~~~~~~~

- Adds a helper method to get the association table for a given Payable.
  [href]

- Switch to onegov.core's generic association implementation.
  [href]

0.1.1 (2017-07-05)
~~~~~~~~~~~~~~~~~~~~~

- Fixes Stripe payment syncing failing if there was a payout.
  [href]

0.1.0 (2017-06-16)
~~~~~~~~~~~~~~~~~~~~~

- Initial Release
